==> v0.13.11.tar.gz: git-next/crates/cli/src/repo/tests/handlers/register_webhook.rs <==
//
use super::*;

#[actix::test]
async fn when_registered_ok_should_send_webhook_registered() -> TestResult {
    //given
    let fs = given::a_filesystem();
    let (open_repository, repo_details) = given::an_open_repository(&fs);

    let registered_webhook = given::a_registered_webhook();
    let mut my_forge = git::MockForgeLike::new();
    my_forge
        .expect_register_webhook()
        .return_once(move |_| Ok(registered_webhook));

    let mut forge = git::MockForgeLike::new();
    forge.expect_duplicate().return_once(|| Box::new(my_forge));

    //when
    let (addr, log) = when::start_actor_with_open_repository(
        Box::new(open_repository),
        repo_details,
        Box::new(forge),
    );
    addr.send(crate::repo::messages::RegisterWebhook::new())
        .await?;
    System::current().stop();

    //then
    tracing::debug!(?log, "");
    log.read().map_err(|e| e.to_string()).map(|l| {
        assert!(l
            .iter()
            .any(|message| message.contains("send: WebhookRegistered")));
    })?;
    Ok(())
}

#[actix::test]
async fn when_registered_error_should_send_notify_user() -> TestResult {
    //given
    let fs = given::a_filesystem();
    let (open_repository, repo_details) = given::an_open_repository(&fs);

    let mut my_forge = git::MockForgeLike::new();
    my_forge.expect_register_webhook().return_once(move |_| {
        Err(git::forge::webhook::Error::FailedToRegister(
            "foo".to_string(),
        ))
    });

    let mut forge = git::MockForgeLike::new();
    forge.expect_duplicate().return_once(|| Box::new(my_forge));

    //when
    let (addr, log) = when::start_actor_with_open_repository(
        Box::new(open_repository),
        repo_details,
        Box::new(forge),
    );
    addr.send(crate::repo::messages::RegisterWebhook::new())
        .await?;
    System::current().stop();

    //then
    tracing::debug!(?log, "");
    log.read()
        .map_err(|e| e.to_string())
        .map(|l| assert!(l.iter().any(|message| message.contains("send: NotifyUser"))))?;
    Ok(())
}

==> v0.14.1.tar.gz: git-next/crates/cli/src/repo/tests/handlers/register_webhook.rs <==
use crate::{repo::messages::RegisterWebhook, tell};

//
use super::*;

#[tokio::test]
async fn when_registered_ok_should_send_webhook_registered() -> TestResult {
    //given
    let fs = given::a_filesystem();
    let (open_repository, repo_details) = given::an_open_repository(&fs);

    let registered_webhook = given::a_registered_webhook();
    let mut forge = git::MockForgeLike::new();
    forge
        .expect_register_webhook()
        .return_once(move |_| Ok(registered_webhook));

    //when
    let (addr, log) = when::start_actor_with_open_repository(
        Box::new(open_repository),
        repo_details,
        Box::new(forge),
    );
    tell!(addr, RegisterWebhook::new())?;
    //then
    tracing::debug!(?log, "");
    log.require_message_containing("send: WebhookRegistered")
        .await?;
    Ok(())
}

#[tokio::test]
async fn when_registered_error_should_send_notify_user() -> TestResult {
    //given
    let fs = given::a_filesystem();
    let (open_repository, repo_details) = given::an_open_repository(&fs);

    let mut forge = git::MockForgeLike::new();
    forge.expect_register_webhook().return_once(move |_| {
        Err(git::forge::webhook::Error::FailedToRegister(
            "foo".to_string(),
        ))
    });

    //when
    let (addr, log) = when::start_actor_with_open_repository(
        Box::new(open_repository),
        repo_details,
        Box::new(forge),
    );
    tell!(addr, crate::repo::messages::RegisterWebhook::new())?;

    //then
    tracing::debug!(?log, "");
    log.require_message_containing("send: NotifyUser").await?;
    Ok(())
}
